
#ifndef _C15_fi719_
#define _C15_fi719_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F606_3221(EIF_REFERENCE);
extern void EIF_Minit719(void);
extern EIF_INTEGER_32 F707_3699(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
